@@ -3,12 +3,11 @@ import logging
 from datetime import datetime
 
 import pytz
-from music.models import Album, Artist, Track
 from scrobbles.models import Scrobble
-
-from vrobbler.apps.scrobbles.musicbrainz import (
-    lookup_album_dict_from_mb,
-    lookup_artist_id_from_mb,
+from music.utils import (
+    get_or_create_album,
+    get_or_create_artist,
+    get_or_create_track,
 )
 
 logger = logging.getLogger(__name__)
@@ -27,6 +26,8 @@ def process_audioscrobbler_tsv_file(file_path, user_tz=None):
         source_id = ""
         for row_num, row in enumerate(rows):
             if row_num in [0, 1, 2]:
+                if "Rockbox" in row[0]:
+                    source = "Rockbox"
                 source_id += row[0] + "\n"
                 continue
             if len(row) > 8:
@@ -35,57 +36,18 @@ def process_audioscrobbler_tsv_file(file_path, user_tz=None):
                     extra={'row': row},
                 )
                 continue
-            artist, artist_created = Artist.objects.get_or_create(name=row[0])
-            if artist_created:
-                artist.musicbrainz_id = lookup_artist_id_from_mb(artist.name)
-                artist.save(update_fields=["musicbrainz_id"])
+            artist = get_or_create_artist(row[0])
+            album = get_or_create_album(row[1])
 
-            album = None
-            album_created = False
-            albums = Album.objects.filter(name=row[1])
-            if albums.count() == 1:
-                album = albums.first()
-            else:
-                for potential_album in albums:
-                    if artist in album.artist_set.all():
-                        album = potential_album
-            if not album:
-                album_created = True
-                album = Album.objects.create(name=row[1])
-                album.save()
-                album.artists.add(artist)
-
-            if album_created:
-                album_dict = lookup_album_dict_from_mb(
-                    album.name, artist_name=artist.name
-                )
-                album.year = album_dict["year"]
-                album.musicbrainz_id = album_dict["mb_id"]
-                album.musicbrainz_releasegroup_id = album_dict["mb_group_id"]
-                album.musicbrainz_albumartist_id = artist.musicbrainz_id
-                album.save(
-                    update_fields=[
-                        "year",
-                        "musicbrainz_id",
-                        "musicbrainz_releasegroup_id",
-                        "musicbrainz_albumartist_id",
-                    ]
-                )
-                album.artists.add(artist)
-                album.fetch_artwork()
-
-            track, track_created = Track.objects.get_or_create(
+            track = get_or_create_track(
                 title=row[2],
+                mbid=row[7],
                 artist=artist,
                 album=album,
+                run_time=row[4],
+                run_time_ticks=row[4] * 1000,
             )
 
-            if track_created:
-                track.musicbrainz_id = row[7]
-                track.run_time = int(row[4])
-                track.run_time_ticks = int(row[4]) * 1000
-                track.save()
-
             timestamp = (
                 datetime.utcfromtimestamp(int(row[6]))
                 .replace(tzinfo=user_tz)
@@ -124,9 +86,7 @@ def undo_audioscrobbler_tsv_import(process_log, dryrun=True):
         logger.warning("No lines in process log found to undo")
         return
 
-    for line_num, line in enumerate(process_log.split('\n')):
-        if line_num == 0:
-            continue
+    for line in process_log.split('\n'):
         scrobble_id = line.split("\t")[0]
         scrobble = Scrobble.objects.filter(id=scrobble_id).first()
         if not scrobble:
